@@ -35,14 +35,15 @@ def show_available_commands(ctx: typer.Context, value: bool = True):
         typer.echo("  • logout                       Log out of your TaskNode account")
         typer.echo("  • resend-verification          Resend the email verification code")
         typer.echo("  • reset-password               Reset your account password")
-        typer.echo("  • whoami                       Show current user information")
+        typer.echo("  • account                      Show account info for the logged in user")
 
         typer.echo("\n🚀 Task Management:")
         typer.echo("  • submit                       Submit a Python script to run")
         typer.echo("  • jobs                         List your TaskNode jobs")
-        typer.echo("  • sample-notebook              Generate a sample Jupyter notebook to test with")
         typer.echo("  • job <job_id || index>        Get status and details for a specific TaskNode job")
         typer.echo("  • download <job_id>            Download all files associated with a specific job")
+        typer.echo("  • sample-notebook              Generate a sample Jupyter notebook to test with")
+        
         typer.echo("\nℹ️  Help:")
         typer.echo("  • help                         Show help for the TaskNode CLI")
 
@@ -119,11 +120,11 @@ def reset_password(
 
 
 @app.command()
-def whoami():
+def account():
     """
     Show information about the currently logged in user.
     """
-    return auth.whoami()
+    return auth.account()
 
 
 @app.command()
@@ -149,17 +150,6 @@ def jobs(offset: int = typer.Option(0, "--offset", "-o", help="Number of jobs to
     return tasks.jobs(offset)
 
 
-@app.command()
-def generate_sample(
-    destination: str = typer.Argument(".", help="The destination directory to copy the notebook to"),
-):
-    """
-    Generate a sample Jupyter notebook in the specified directory.
-    The notebook is copied from the TaskNode repository's test.ipynb.
-    """
-    return tasks.generate_sample(destination)
-
-
 @app.command()
 def job(
     job_id: str = typer.Argument(
@@ -207,5 +197,16 @@ def download(
     return tasks.download_job_files(job_id, destination)
 
 
+@app.command()
+def generate_sample(
+    destination: str = typer.Argument(".", help="The destination directory to copy the notebook to"),
+):
+    """
+    Generate a sample Jupyter notebook in the specified directory.
+    The notebook is copied from the TaskNode repository's test.ipynb.
+    """
+    return tasks.generate_sample(destination)
+
+
 if __name__ == "__main__":
     app()
